# Bambot

Bambot is a Python package for interfacing with Bam foundational AI models which simplifies the process of integrating advanced data capabilities into your apps.

## Installation

To install Bambot, run the following command:

```sh
pip install bambot